summaryrefslogtreecommitdiff
path: root/res/res_statsd.c
diff options
context:
space:
mode:
Diffstat (limited to 'res/res_statsd.c')
-rw-r--r--res/res_statsd.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/res/res_statsd.c b/res/res_statsd.c
index 221b359c9..8565e41cb 100644
--- a/res/res_statsd.c
+++ b/res/res_statsd.c
@@ -381,13 +381,13 @@ static int reload_module(void)
}
}
/* The priority of this module is set to be as low as possible, since it could
* be used by any other sort of module.
*/
AST_MODULE_INFO(ASTERISK_GPL_KEY, AST_MODFLAG_GLOBAL_SYMBOLS | AST_MODFLAG_LOAD_ORDER, "Statsd client support",
.support_level = AST_MODULE_SUPPORT_EXTENDED,
.load = load_module,
.unload = unload_module,
.reload = reload_module,
- .load_pri = 0,
+ .load_pri = AST_MODPRI_REALTIME_DRIVER + 5,
);
@@ -381,13 +381,13 @@ static int reload_module(void)
}
}
-/* The priority of this module is set to be as low as possible, since it could
- * be used by any other sort of module.
+/* The priority of this module is set just after realtime, since it loads
+ * configuration and could be used by any other sort of module.
*/
AST_MODULE_INFO(ASTERISK_GPL_KEY, AST_MODFLAG_GLOBAL_SYMBOLS | AST_MODFLAG_LOAD_ORDER, "Statsd client support",